#ifndef INC_ncoEnumTokenTypes_hpp_
#define INC_ncoEnumTokenTypes_hpp_

/* $ANTLR 2.7.7 (2006-11-01): "ncoGrammer.g" -> "ncoEnumTokenTypes.hpp"$ */

#ifndef CUSTOM_API
# define CUSTOM_API
#endif

	enum {
		EOF_ = 1,
		NULL_NODE = 4,
		BLOCK = 5,
		ARG_LIST = 6,
		DMN_LIST = 7,
		DMN_LIST_P = 8,
		DMN_ARG_LIST = 9,
		LMT_LIST = 10,
		VALUE_LIST = 11,
		FUNC_ARG = 12,
		LMT = 13,
		EXPR = 14,
		FEXPR = 15,
		POST_INC = 16,
		POST_DEC = 17,
		UTIMES = 18,
		PROP = 19,
		FOR2 = 20,
		NORET = 21,
		ATAN2 = 22,
		WHERE_ASSIGN = 23,
		MISS2ZERO = 24,
		VSORT = 25,
		VRSORT = 26,
		VABS = 27,
		VSQR2 = 28,
		DEFDIM = 29,
		SEMI = 30,
		DEFDIMA = 31,
		DEFDIMU = 32,
		LPAREN = 33,
		NSTRING = 34,
		COMMA = 35,
		RPAREN = 36,
		WHILE = 37,
		BREAK = 38,
		CONTINUE = 39,
		IF = 40,
		ELSE = 41,
		WHERE = 42,
		ELSEWHERE = 43,
		LCURL = 44,
		RCURL = 45,
		FOR = 46,
		COLON = 47,
		LSQUARE = 48,
		VAR_ID = 49,
		DIM_ID = 50,
		RSQUARE = 51,
		DIVIDE = 52,
		DIM_MTD_ID = 53,
		ATT_ID = 54,
		CALL_REF = 55,
		TIMES = 56,
		DOT = 57,
		FUNC = 58,
		INC = 59,
		DEC = 60,
		LNOT = 61,
		PLUS = 62,
		MINUS = 63,
		CARET = 64,
		MOD = 65,
		FLTHAN = 66,
		FGTHAN = 67,
		LTHAN = 68,
		GTHAN = 69,
		GEQ = 70,
		LEQ = 71,
		EQ = 72,
		NEQ = 73,
		LAND = 74,
		LOR = 75,
		QUESTION = 76,
		ASSIGN = 77,
		PLUS_ASSIGN = 78,
		MINUS_ASSIGN = 79,
		TIMES_ASSIGN = 80,
		DIVIDE_ASSIGN = 81,
		NCAP_FLOAT = 82,
		NCAP_DOUBLE = 83,
		NCAP_INT = 84,
		NCAP_BYTE = 85,
		NCAP_UBYTE = 86,
		NCAP_SHORT = 87,
		NCAP_USHORT = 88,
		NCAP_UINT = 89,
		NCAP_INT64 = 90,
		NCAP_UINT64 = 91,
		N4STRING = 92,
		DIM_ID_SIZE = 93,
		NRootAST = 94,
		SHIFTL = 95,
		SHIFTR = 96,
		QUOTE = 97,
		DGT = 98,
		LPH = 99,
		LPHDGT = 100,
		XPN = 101,
		VAR_NM_QT = 102,
		BLASTOUT = 103,
		UNUSED_OPS = 104,
		WS = 105,
		CXX_COMMENT = 106,
		C_COMMENT = 107,
		NUMBER_DOT = 108,
		NUMBER = 109,
		VAR_ATT = 110,
		VAR_ATT_QT = 111,
		STR_ATT_QT = 112,
		DIM_QT = 113,
		DIM_VAL = 114,
		INCLUDE = 115,
		LMT_DMN = 116,
		NULL_TREE_LOOKAHEAD = 3
	};
#endif /*INC_ncoEnumTokenTypes_hpp_*/
